{% comment %} Copyright (C) 2017-2024 The Software Heritage developers See the AUTHORS file at the top-level directory of this distribution License: GNU Affero General Public License version 3, or any later version See top-level LICENSE file for more information {% endcomment %} {% load static %} {% load swh_templatetags %} {% if readme_name %}

#### {{ readme_name }}

Loading {{ readme_name }} ...

{% if readme_html %}
{% elif readme_url is None %}
{% elif readme_name.lower == 'readme' or readme_name.lower == 'readme.txt' %}
{% elif readme_name.lower == 'readme.org' %}
{% else %}
{% endif %} {% endif %}